## Headings
# Heading 1
## Heading 2
### Heading 3
#### Heading 4
##### Heading 5
###### Heading 6

## Linebreak

a linebreak  
is 2 or more spaces  
on a row of text

## Italics
*This text* is italic

_This text_ is italic

## Strong 
**This text** is strong

__This text__ is strong

## Strikethrough
~~This text~~ is strikethrough

## Horizontal Rule

---
___

## Blockquote
> This is a quote

## Links
[DetaMVC](http://detamvc.deta.dev)

[DetaMVC (with Tooltip)](http://detamvc.deta.dev "DetaMVC")

## Unordered List
* Item 1
* Item 2
* Item 3
  * Nested Item 1
  * Nested Item 2

## Ordered List
1. Item 1
1. Item 2
1. Item 3



## Images

**from the web**  
![Markdown Logo](https://markdown-here.com/img/icon256.png)

**from local assets**  
![Image from assets](/assets/images/logo.svg)


## Code Blocks

**Inline Code Block**  
`<p>This is a paragraph</p>`  

**Multi-line Code Block**  

```bash
  npm install

  npm start
```

```javascript
  function add(num1, num2) {
    return num1 + num2;
  }
```

```python
  def add(num1, num2):
    return num1 + num2
```

## Tables
| Name     | Email          |
| -------- | -------------- |
| John Doe | john@gmail.com |
| Jane Doe | jane@gmail.com |

## Task List

- [x] Task 1  
- [x] Task 2  
- [ ] Task 3  